@@ -3,7 +3,7 @@ import { useParams } from 'react-router-dom-v5-compat';
 import { Page } from 'app/core/components/Page/Page';
 import { getNavModel } from 'app/core/selectors/navModel';
 import { getDataSourceLoadingNav } from 'app/features/datasources/state/navModel';
-import { StoreState, useSelector } from 'app/types';
+import { StoreState, useSelector } from 'app/types/store';
 
 import DataSourcePermissions from './DataSourcePermissions';
 
